"use strict";(self.webpackChunkreally_simple_ssl=self.webpackChunkreally_simple_ssl||[]).push([[829],{3829:(e,s,t)=>{t.r(s),t.d(s,{default:()=>c});var m=t(9307);const l=()=>(0,m.createElement)("div",{className:"rsssl-wizard-menu rsssl-grid-item rsssl-menu-placeholder"},(0,m.createElement)("div",{className:"rsssl-grid-item-header"},(0,m.createElement)("h1",{className:"rsssl-h4"})),(0,m.createElement)("div",{className:"rsssl-grid-item-content"}));var a=t(5736),n=t(2485);const r=e=>{const{selectedSubMenuItem:s,selectedMainMenuItem:t,subMenu:l,menu:i}=(0,n.Z)();let u=s===e.menuItem.id;if(e.menuItem.menu_items)for(const t of e.menuItem.menu_items)t.id===s&&(u=!0);let c=u?" rsssl-active":"";c+=e.menuItem.featured?" rsssl-featured":"",c+=e.menuItem.premium&&!rsssl_settings.pro_plugin_active?" rsssl-premium":"";let d="#"+t+"/"+e.menuItem.id;return(0,m.createElement)(m.Fragment,null,e.menuItem.visible&&(0,m.createElement)("div",{className:"rsssl-menu-item"+c},(0,m.createElement)("a",{href:d},(0,m.createElement)("span",null,e.menuItem.title),e.menuItem.featured&&(0,m.createElement)(m.Fragment,null,(0,m.createElement)("span",{className:"rsssl-menu-item-beta-pill"},(0,a.__)("Beta","really-simple-ssl")))),e.menuItem.menu_items&&u&&(0,m.createElement)("div",{className:"rsssl-submenu-item"},e.menuItem.menu_items.map(((e,s)=>e.visible&&(0,m.createElement)(r,{key:"submenuItem"+s,menuItem:e}))))))},i=r;var u=t(1789);const c=()=>{const{subMenu:e,hasPremiumItems:s,subMenuLoaded:t}=(0,n.Z)(),{licenseStatus:r}=(0,u.Z)();return t?(0,m.createElement)("div",{className:"rsssl-wizard-menu rsssl-grid-item"},(0,m.createElement)("div",{className:"rsssl-grid-item-header"},(0,m.createElement)("h1",{className:"rsssl-h4"},e.title)),(0,m.createElement)("div",{className:"rsssl-grid-item-content"},(0,m.createElement)("div",{className:"rsssl-wizard-menu-items"},e.menu_items.map(((e,s)=>(0,m.createElement)(i,{key:"menuItem-"+s,menuItem:e}))),s&&!rsssl_settings.is_premium&&"valid"!==r&&(0,m.createElement)("div",{className:"rsssl-premium-menu-item"},(0,m.createElement)("div",null,(0,m.createElement)("a",{target:"_blank",href:rsssl_settings.upgrade_link,className:"button button-black"},(0,a.__)("Upgrade","really-simple-ssl")))))),(0,m.createElement)("div",{className:"rsssl-grid-item-footer"})):(0,m.createElement)(l,null)}},1789:(e,s,t)=>{t.d(s,{Z:()=>m});const m=(0,t(270).Ue)(((e,s)=>({licenseStatus:rsssl_settings.licenseStatus,setLicenseStatus:s=>e((e=>({licenseStatus:s})))})))}}]);